==> grunt-lint-pattern-0.1.3.tgz: package/README.md <==
# grunt-lint-pattern

> Find a pattern in files.  Error if any match.

## Getting Started
This plugin requires Grunt `~0.4.1`

If you haven't used [Grunt](http://gruntjs.com/) before, be sure to check out the [Getting Started](http://gruntjs.com/getting-started) guide, as it explains how to create a [Gruntfile](http://gruntjs.com/sample-gruntfile) as well as install and use Grunt plugins. Once you're familiar with that process, you may install this plugin with this command:

```shell
npm install grunt-lint-pattern --save-dev
```

Once the plugin has been installed, it may be enabled inside your Gruntfile with this line of JavaScript:

```js
grunt.loadNpmTasks('grunt-lint-pattern');
```

## The "lint_pattern" task

### Overview
In your project's Gruntfile, add a section named `lint_pattern` to the data object passed into `grunt.initConfig()`.

```js
grunt.initConfig({
  lint_pattern: {
    your_target: {
      options: {
        rules: [
          {
            pattern: /console\./;
            message: 'Calling "console." is not allowed.'
          },
        ],
      },
      files: {
        '**.js',
      },
    },
    your_target: {
      options: {
        rules: [
          {
            pattern: /moz-border-radius/;
            message: 'Don't use vendor prefixes for the border-radius property.'
          },
          {
            pattern: /!important/;
            message: 'Do not use "!important".'
          },
        ],
      },
      files: {
        '**.css',
      },
    },
  },
})
```

### Options

#### options.rules
Type: `Array`
Required

An array of "rules" that will be used to test files.  Rules have the form:

##### pattern
Type: `RegExp`
Required

A RegExp that will be used to test files.

##### pattern
Type: `string`
Optional

A message that will print when pattern is found.

### Usage Examples

## Contributing
In lieu of a formal styleguide, take care to maintain the existing coding style. Add unit tests for any new or changed functionality. Lint and test your code using [Grunt](http://gruntjs.com/).

## Release History
* 0.1 Initial release

==> grunt-lint-pattern-0.1.4.tgz: package/README.md <==
# grunt-lint-pattern

> Find a pattern in files.  Error if any match.

## Getting Started
This plugin requires Grunt `~0.4.1`

If you haven't used [Grunt](http://gruntjs.com/) before, be sure to check out the [Getting Started](http://gruntjs.com/getting-started) guide, as it explains how to create a [Gruntfile](http://gruntjs.com/sample-gruntfile) as well as install and use Grunt plugins. Once you're familiar with that process, you may install this plugin with this command:

```shell
npm install grunt-lint-pattern --save-dev
```

Once the plugin has been installed, it may be enabled inside your Gruntfile with this line of JavaScript:

```js
grunt.loadNpmTasks('grunt-lint-pattern');
```

## The "lint_pattern" task

### Overview
In your project's Gruntfile, add a section named `lint_pattern` to the data object passed into `grunt.initConfig()`.

```js
grunt.initConfig({
  lint_pattern: {
    your_first_target: {
      options: {
        rules: [
          {
            pattern: /console\./,
            message: 'Do not call "console".'
          },
        ],
      },
      files: {
        '**.js',
      },
    },
    your_second_target: {
      options: {
        rules: [
          {
            pattern: /moz-border-radius/,
            message: 'Do not use vendor prefixes for the border-radius property.'
          },
          {
            pattern: /!important/,
            message: 'Do not use "!important".'
          },
          {
            pattern: /@import\s+/,
            message: 'Do not use import statements',
            filter: function(src) {

            }
          },
        ],
      },
      files: {
        '**.css',
      },
    },
  },
})
```

### Options

#### options.rules
Type: `Array`
Required

An array of "rules" that will be used to test files.  Rules have the form:

##### pattern
Type: `RegExp`
Required

A RegExp that will be used to test files.

##### pattern
Type: `string`
Optional

A message that will print when pattern is found.

##### filter
Type: `function`
Optional

If present, this function will be called once for each matching file to decide whether to test this rule.  Return `true` to allow checking this file.  Return `false` to skip checking this file.

This is particularly useful if you are checking a large list of rules over a large list of files and a small number of files that should be excluded by certain rules.  The advantage of filtering out the few exclusions compared to creating multiple targets is that the files need only be read from disk once if there's a single target.


## Contributing
In lieu of a formal styleguide, take care to maintain the existing coding style. Add unit tests for any new or changed functionality. Lint and test your code using [Grunt](http://gruntjs.com/).

## Release History
* 0.1.0 Initial release
* 0.1.4 add `filter` option
